/*==============================================================*/
/* DBMS name:      MySQL 5.0                                    */
/* Created on:     2013-05-03 11:09:30                          */
/*==============================================================*/


/*==============================================================*/
/* Table: arbitre                                               */
/*==============================================================*/
create table arbitre
(
   arbitre_numero       int not null,
   abtire_nom           varchar(64) not null,
   arbitre_prenom       varchar(64) not null,
   arbitre_telephone    varchar(16),
   arbitre_adresse      varchar(256),
   arbitre_courriel     varchar(256),
   arbitre_commentaire  varchar(512),
   primary key (arbitre_numero)
);

/*==============================================================*/
/* Table: arbitre_partie                                        */
/*==============================================================*/
create table arbitre_partie
(
   arbitre_position_numero int not null,
   partie_numero        int not null,
   arbitre_numero       int not null,
   primary key (arbitre_position_numero, partie_numero, arbitre_numero)
);

/*==============================================================*/
/* Table: arbitre_position                                      */
/*==============================================================*/
create table arbitre_position
(
   arbitre_position_numero int not null,
   arbitre_position_nom varchar(64) not null,
   primary key (arbitre_position_numero)
);

/*==============================================================*/
/* Table: categorie                                             */
/*==============================================================*/
create table categorie
(
   categorie_numero     int not null,
   categorie_nom        varchar(128) not null,
   categorie_niveau     varchar(8) not null,
   primary key (categorie_numero)
);

/*==============================================================*/
/* Table: entraineur                                            */
/*==============================================================*/
create table entraineur
(
   entraineur_numero    int not null,
   entraineur_nom       varchar(64) not null,
   entraineur_prenom    varchar(64) not null,
   entraineur_telephone varchar(16),
   entraineur_adresse   varchar(256),
   entraineur_courriel  varchar(256),
   entraineur_commentaire varchar(512),
   primary key (entraineur_numero)
);

/*==============================================================*/
/* Table: entraineur_equipe                                     */
/*==============================================================*/
create table entraineur_equipe
(
   type_entraineur_numero int not null,
   entraineur_numero    int not null,
   equipe_numero        int not null,
   primary key (type_entraineur_numero, entraineur_numero, equipe_numero)
);

/*==============================================================*/
/* Table: equipe                                                */
/*==============================================================*/
create table equipe
(
   equipe_numero        int not null,
   categorie_numero     int,
   equipe_nom           varchar(128) not null,
   primary key (equipe_numero)
);

/*==============================================================*/
/* Table: marqueur                                              */
/*==============================================================*/
create table marqueur
(
   marqueur_numero      int not null,
   marqueur_nom         varchar(64) not null,
   marqueur_prenom      varchar(64) not null,
   marqueur_telephone   varchar(16),
   marqueur_adresse     varchar(256),
   marqueur_courriel    varchar(256),
   marqueur_commentaire varchar(512),
   primary key (marqueur_numero)
);

/*==============================================================*/
/* Table: marqueur_partie                                       */
/*==============================================================*/
create table marqueur_partie
(
   partie_numero        int not null,
   marqueur_position_numero int not null,
   marqueur_numero      int not null,
   primary key (partie_numero, marqueur_position_numero, marqueur_numero)
);

/*==============================================================*/
/* Table: marqueur_position                                     */
/*==============================================================*/
create table marqueur_position
(
   marqueur_position_numero int not null,
   marqueur_position_nom varchar(64) not null,
   primary key (marqueur_position_numero)
);

/*==============================================================*/
/* Table: partie                                                */
/*==============================================================*/
create table partie
(
   partie_numero        int not null,
   equipe_numero_local  int,
   equipe_numero_visite int,
   partie_status_numero int,
   terrain_numero       int,
   categorie_numero     int,
   partie_commentaire   varchar(512),
   partie_points_local  int,
   partie_points_visite int,
   partie_heure_debut   time,
   partie_heure_de_fin  time,
   partie_heure_debut_prevue time,
   partie_nombre_manches int,
   partie_date          date,
   primary key (partie_numero)
);

/*==============================================================*/
/* Table: partie_status                                         */
/*==============================================================*/
create table partie_status
(
   partie_status_numero int not null,
   partie_status_nom    varchar(64),
   partie_status_image  varchar(64),
   primary key (partie_status_numero)
);

/*==============================================================*/
/* Table: terrain                                               */
/*==============================================================*/
create table terrain
(
   terrain_numero       int not null,
   ville_numero         int,
   terrain_nom          varchar(256) not null,
   terrain_adresse      varchar(256) not null,
   terrain_commentaires varchar(512),
   primary key (terrain_numero)
);

/*==============================================================*/
/* Table: type_entraineur                                       */
/*==============================================================*/
create table type_entraineur
(
   type_entraineur_numero int not null,
   type_entraineur_nom  varchar(64),
   primary key (type_entraineur_numero)
);

/*==============================================================*/
/* Table: ville                                                 */
/*==============================================================*/
create table ville
(
   ville_numero         int not null,
   ville_nom            varchar(256) not null,
   primary key (ville_numero)
);

alter table arbitre_partie add constraint fk_arbitre_partie foreign key (arbitre_position_numero)
      references arbitre_position (arbitre_position_numero) on delete restrict on update restrict;

alter table arbitre_partie add constraint fk_arbitre_partie2 foreign key (partie_numero)
      references partie (partie_numero) on delete restrict on update restrict;

alter table arbitre_partie add constraint fk_arbitre_partie3 foreign key (arbitre_numero)
      references arbitre (arbitre_numero) on delete restrict on update restrict;

alter table entraineur_equipe add constraint fk_entraineur_equipe foreign key (type_entraineur_numero)
      references type_entraineur (type_entraineur_numero) on delete restrict on update restrict;

alter table entraineur_equipe add constraint fk_entraineur_equipe2 foreign key (entraineur_numero)
      references entraineur (entraineur_numero) on delete restrict on update restrict;

alter table entraineur_equipe add constraint fk_entraineur_equipe3 foreign key (equipe_numero)
      references equipe (equipe_numero) on delete restrict on update restrict;

alter table equipe add constraint fk_equipe_categorie foreign key (categorie_numero)
      references categorie (categorie_numero) on delete restrict on update restrict;

alter table marqueur_partie add constraint fk_marqueur_partie foreign key (partie_numero)
      references partie (partie_numero) on delete restrict on update restrict;

alter table marqueur_partie add constraint fk_marqueur_partie2 foreign key (marqueur_position_numero)
      references marqueur_position (marqueur_position_numero) on delete restrict on update restrict;

alter table marqueur_partie add constraint fk_marqueur_partie3 foreign key (marqueur_numero)
      references marqueur (marqueur_numero) on delete restrict on update restrict;

alter table partie add constraint fk_a foreign key (partie_status_numero)
      references partie_status (partie_status_numero) on delete restrict on update restrict;

alter table partie add constraint fk_equipe_local foreign key (equipe_numero_visite)
      references equipe (equipe_numero) on delete restrict on update restrict;

alter table partie add constraint fk_equipe_visite foreign key (equipe_numero_local)
      references equipe (equipe_numero) on delete restrict on update restrict;

alter table partie add constraint fk_partie_categorie foreign key (categorie_numero)
      references categorie (categorie_numero) on delete restrict on update restrict;

alter table partie add constraint fk_se_joue foreign key (terrain_numero)
      references terrain (terrain_numero) on delete restrict on update restrict;

alter table terrain add constraint fk_se_trouve foreign key (ville_numero)
      references ville (ville_numero) on delete restrict on update restrict;

